@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.208';
+our $VERSION = '0.209';
 
 =head1 NAME
 
@@ -13,13 +13,17 @@ Tickit::Widget::Table - table widget with support for scrolling/paging
 
 =head1 VERSION
 
-version 0.208
+version 0.209
 
 =head1 SYNOPSIS
 
+ #!/usr/bin/env perl
+ use strict;
+ use warnings;
+ 
  use Tickit;
  use Tickit::Widget::Table;
-
+ 
  my $tbl = Tickit::Widget::Table->new;
  $tbl->add_column(
  	label => 'Left',
@@ -30,7 +34,7 @@ version 0.208
  	label => 'Second column',
  	align => 'centre'
  );
- $tbl->add_row('left', 'middle') for 1..100;
+ $tbl->adapter->push([ map [qw(left middle)], 1..100 ]);
  Tickit->new(root => $tbl)->run;
 
 =head1 DESCRIPTION
